==> location_plugin-0.0.1.tar.gz: ios/Classes/LocationpluginPlugin.m <==
#import "LocationpluginPlugin.h"
#import <TencentLBS/TencentLBS.h>
@interface LocationpluginPlugin()<TencentLBSLocationManagerDelegate>
@property(nonatomic, copy) FlutterResult callresult;
@property (readwrite, nonatomic, strong) TencentLBSLocationManager *locationManager;
@end
@implementation LocationpluginPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
                                     methodChannelWithName:@"location_plugin"
                                     binaryMessenger:[registrar messenger]];
    LocationpluginPlugin* instance = [[LocationpluginPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if (self.callresult == NULL) {
        self.callresult = result;
    }
    if ([@"getMyLocation" isEqualToString:call.method]) {
        if (self.locationManager == NULL) {
            self.locationManager =  [[TencentLBSLocationManager alloc] init];
            self.locationManager.apiKey = @"AT2BZ-GO63R-CHVWD-WUEPB-K74NV-56FOG";
            self.locationManager.pausesLocationUpdatesAutomatically = false;
            self.locationManager.requestLevel = TencentLBSRequestLevelName;
            self.locationManager.delegate = self;
            CLAuthorizationStatus authorizationStatus= [CLLocationManager authorizationStatus];
            if (authorizationStatus == kCLAuthorizationStatusNotDetermined) {
                [self.locationManager requestWhenInUseAuthorization];
            }
        }
        [self.locationManager requestLocationWithCompletionBlock:^(TencentLBSLocation * _Nullable location, NSError * _Nullable error) {
            if (error) {
                result(@{@"error": error.description});
                return;
            }
            NSDictionary *resultDic = @{
                @"latitude": [NSNumber numberWithDouble:location.location.coordinate.latitude],
                @"longitude": [NSNumber numberWithDouble:location.location.coordinate.longitude],
                @"name": location.name,
                @"address": location.address
            };
            result(resultDic);
        }];
        //    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}

#pragma mark - TencentLBSLocationManagerDelegate

- (void)tencentLBSLocationManager:(TencentLBSLocationManager *)manager
                 didFailWithError:(NSError *)error {
    CLAuthorizationStatus authorizationStatus = [CLLocationManager authorizationStatus];
    if (authorizationStatus == kCLAuthorizationStatusDenied || authorizationStatus == kCLAuthorizationStatusRestricted) {
        self.callresult(@{@"error": @"定位权限未开启"});
    } else {
        self.callresult(@{@"error": error.description});
    }
}

@end

==> location_plugin-0.0.2.tar.gz: ios/Classes/LocationpluginPlugin.m <==
#import "LocationpluginPlugin.h"
#import <TencentLBS/TencentLBS.h>
@interface LocationpluginPlugin()<TencentLBSLocationManagerDelegate>
@property(nonatomic, copy) FlutterResult callresult;
@property (readwrite, nonatomic, strong) TencentLBSLocationManager *locationManager;
@end
@implementation LocationpluginPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
    FlutterMethodChannel* channel = [FlutterMethodChannel
                                     methodChannelWithName:@"location_plugin"
                                     binaryMessenger:[registrar messenger]];
    LocationpluginPlugin* instance = [[LocationpluginPlugin alloc] init];
    [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    if (self.callresult == NULL) {
        self.callresult = result;
    }
    if ([@"getMyLocation" isEqualToString:call.method]) {
        if (self.locationManager == NULL) {
            self.locationManager =  [[TencentLBSLocationManager alloc] init];
            self.locationManager.apiKey = @"AT2BZ-GO63R-CHVWD-WUEPB-K74NV-56FOG";
            self.locationManager.pausesLocationUpdatesAutomatically = false;
            self.locationManager.requestLevel = TencentLBSRequestLevelName;
            self.locationManager.delegate = self;
            CLAuthorizationStatus authorizationStatus= [CLLocationManager authorizationStatus];
            if (authorizationStatus == kCLAuthorizationStatusNotDetermined) {
                [self.locationManager requestWhenInUseAuthorization];
            }
        }
        [self.locationManager requestLocationWithCompletionBlock:^(TencentLBSLocation * _Nullable location, NSError * _Nullable error) {
            if (error) {
                result(@{@"error": error.description});
                return;
            }

            NSDictionary *resultDic = @{
                @"latitude": [NSNumber numberWithDouble:location.location.coordinate.latitude],
                @"longitude": [NSNumber numberWithDouble:location.location.coordinate.longitude],
                @"name": location.name,
                @"address": location.address,
                @"city": location.city,
                @"cityCode": location.code,
                @"province": location.province,
                @"district": location.district,
                @"street": location.street,
                @"streetNo": location.street_no,
                @"town": location.town,
                @"village": location.village
            };
            result(resultDic);
        }];
        //    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
    } else {
        result(FlutterMethodNotImplemented);
    }
}

#pragma mark - TencentLBSLocationManagerDelegate

- (void)tencentLBSLocationManager:(TencentLBSLocationManager *)manager
                 didFailWithError:(NSError *)error {
    CLAuthorizationStatus authorizationStatus = [CLLocationManager authorizationStatus];
    if (authorizationStatus == kCLAuthorizationStatusDenied || authorizationStatus == kCLAuthorizationStatusRestricted) {
        self.callresult(@{@"error": @"定位权限未开启"});
    } else {
        self.callresult(@{@"error": error.description});
    }
}

@end
